==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/cloudcredential/v1/CredentialsRequestStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CredentialsRequestStatusBuilder extends io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusFluentImpl<io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatus,io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusBuilder>{
  public CredentialsRequestStatusBuilder() {
    this(false);
  }
  public CredentialsRequestStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new CredentialsRequestStatus(), validationEnabled);
  }
  public CredentialsRequestStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CredentialsRequestStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CredentialsRequestStatus(), validationEnabled);
  }
  public CredentialsRequestStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatus instance) {
    this(fluent, instance, false);
  }
  public CredentialsRequestStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withLastSyncCloudCredsSecretResourceVersion(instance.getLastSyncCloudCredsSecretResourceVersion()); 
    fluent.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    fluent.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    fluent.withProviderStatus(instance.getProviderStatus()); 
    fluent.withProvisioned(instance.getProvisioned()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CredentialsRequestStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatus instance) {
    this(instance,false);
  }
  public CredentialsRequestStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withLastSyncCloudCredsSecretResourceVersion(instance.getLastSyncCloudCredsSecretResourceVersion()); 
    this.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    this.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    this.withProviderStatus(instance.getProviderStatus()); 
    this.withProvisioned(instance.getProvisioned()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestStatus build() {
    CredentialsRequestStatus buildable = new CredentialsRequestStatus(fluent.getConditions(),fluent.getLastSyncCloudCredsSecretResourceVersion(),fluent.getLastSyncGeneration(),fluent.getLastSyncTimestamp(),fluent.getProviderStatus(),fluent.getProvisioned());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CredentialsRequestStatusBuilder that = (CredentialsRequestStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/cloudcredential/v1/CredentialsRequestStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CredentialsRequestStatusBuilder extends CredentialsRequestStatusFluentImpl<CredentialsRequestStatusBuilder> implements VisitableBuilder<CredentialsRequestStatus,CredentialsRequestStatusBuilder>{
  public CredentialsRequestStatusBuilder() {
    this(false);
  }
  public CredentialsRequestStatusBuilder(Boolean validationEnabled) {
    this(new CredentialsRequestStatus(), validationEnabled);
  }
  public CredentialsRequestStatusBuilder(CredentialsRequestStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CredentialsRequestStatusBuilder(CredentialsRequestStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CredentialsRequestStatus(), validationEnabled);
  }
  public CredentialsRequestStatusBuilder(CredentialsRequestStatusFluent<?> fluent,CredentialsRequestStatus instance) {
    this(fluent, instance, false);
  }
  public CredentialsRequestStatusBuilder(CredentialsRequestStatusFluent<?> fluent,CredentialsRequestStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withLastSyncCloudCredsSecretResourceVersion(instance.getLastSyncCloudCredsSecretResourceVersion()); 
    fluent.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    fluent.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    fluent.withProviderStatus(instance.getProviderStatus()); 
    fluent.withProvisioned(instance.getProvisioned()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CredentialsRequestStatusBuilder(CredentialsRequestStatus instance) {
    this(instance,false);
  }
  public CredentialsRequestStatusBuilder(CredentialsRequestStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withLastSyncCloudCredsSecretResourceVersion(instance.getLastSyncCloudCredsSecretResourceVersion()); 
    this.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    this.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    this.withProviderStatus(instance.getProviderStatus()); 
    this.withProvisioned(instance.getProvisioned()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CredentialsRequestStatusFluent<?> fluent;
  Boolean validationEnabled;
  public CredentialsRequestStatus build() {
    CredentialsRequestStatus buildable = new CredentialsRequestStatus(fluent.getConditions(),fluent.getLastSyncCloudCredsSecretResourceVersion(),fluent.getLastSyncGeneration(),fluent.getLastSyncTimestamp(),fluent.getProviderStatus(),fluent.getProvisioned());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
